# default to enable (and build only) mpi
%bcond_without                  mpi
#reminder: pay attention to NOT compile openmpi with
#--enable-rpath-wrappers, otherwise paraview-mpi binaries end up
#having a RUNPATH taking precedence over /etc/ld.conf.d/ settings

%define baseversion             %(echo %{version} | cut -d. -f-2)
%define namever                 %{name}-%{baseversion}

%define staticdevelname         %mklibname -d -s %{name}

# some sources will need more than 4GB of memory to built
# (vtkExtractVOI.cxx), gcc gets killed, let's reduce on arm and
# i586 (mind the 32h limit)
%ifarch %{arm} %{ix86}
%define _smp_ncpus_max          $(expr $(nproc) / 2)
%define paraflags               %{optflags} -O1
%else
%define _smp_ncpus_max          $(expr $(nproc) / 2)
%define paraflags               %{optflags}
%endif

# Do not provide anything in paraview's library directory
%global __provides_exclude_from ^(%{_libdir}/paraview/|%{_libdir}/.*/lib/paraview/).*$

# Do not require anything provided in paraview's library directory
# This list needs to be maintained by hand
%global __requires_exclude ^lib(IceT|pq|QtTesting|vtk|protobuf|catalyst).*

Name:           paraview
Version:        5.10.1
Release:        %mkrel 7
Summary:        Parallel visualization application
Group:          Sciences/Other
License:        BSD
URL:            https://www.paraview.org/
Source0:        https://www.paraview.org/files/v%{baseversion}/ParaView-v%{version}.tar.xz
Source1:        paraview.xml
Source2:        paraview.desktop
#remove source files corresponding to system libraries to force errors
#if they were silently built
Source3:        cleansources.bash

# Fix cmake files install location
# https://gitlab.kitware.com/paraview/paraview/issues/19724
Patch0:         paraview-cmakedir.patch

# Fix linking
Patch3:		paraview-5.10.1-vtk-linking.patch

# Fix build with python >= 3.7
Patch5:         ParaView-v5.8.0-PyUnicode_AsUTF8-const-char.patch

#https://gitlab.kitware.com/paraview/paraview/-/issues/20289
#modifed from https://gitlab.kitware.com/vtk/vtk/uploads/a5354808a4167e6fa9208c8c03ffd105/vtk-freetype-2.10.3-provide-FT_CALLBACK_DEF.patch
Patch9: vtk-freetype-2.10.3-provide-FT_CALLBACK_DEF.patch

# Build with ffmpeg 5.0
# https://gitlab.kitware.com/vtk/vtk/-/commit/948b6f491294f1a9aa48ba265adae28291de95a0
Patch10: vtk-9.1.0-ffmpeg.patch

# Fix build with external fmt : vtkPVStringFormatter: Use custom dynamic arg store 
# https://gitlab.kitware.com/paraview/paraview/-/merge_requests/5618/diffs?commit_id=a40d6a3d43d7d77f5869e6c047aa4236caa24e92
Patch11: paraview-5.10.1-fix-fmt-changes.patch


%if %{with mpi}
BuildRequires:  openmpi-devel
BuildRequires:  gcc-gfortran
%rename         paraview-mpi
Requires:       openmpi
%endif
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  ffmpeg-devel
#(eatdirt) broken
BuildRequires:  gl2ps-devel >= 1.4.0
BuildRequires:  gnuplot
BuildRequires:  graphviz
BuildRequires:  hdf5
BuildRequires:  hdf5-devel
BuildRequires:  imagemagick
BuildRequires:  jsoncpp-devel
BuildRequires:  netcdf-cxx-devel
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(zlib)

BuildRequires:  python3-mpi4py-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  qtxmlpatterns5-xmlpatterns
BuildRequires:  pkgconfig(Qt5XmlPatterns)
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(tk)
BuildRequires:  pugixml-devel
BuildRequires:  lz4-devel
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(proj)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(fmt)
#(eatdirt) broken
#BuildRequires:  osmesa-devel
BuildRequires:  wget
BuildRequires:  python3dist(pygments)
BuildRequires:  cgns-devel
#(eatdirt) broken in spite of patching
#BuildRequires:  libharu-devel
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  double-conversion-devel
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libutf8proc)
BuildRequires:  utf8cpp-devel

Requires:       python3dist(pygobject)
Requires:       python3dist(pygments)
Requires:       qt5-database-plugin-sqlite

Obsoletes:      %{name}-data <= 5.0

%description
ParaView is an open-source, multi-platform data analysis and
visualization application. ParaView users can quickly build
visualizations to analyze their data using qualitative and
quantitative techniques. The data exploration can be done
interactively in 3D or programmatically using ParaView’s batch
processing capabilities. ParaView was developed to analyze extremely
large datasets using distributed memory computing resources. It can be
run on supercomputers to analyze datasets of petascale as well as on
laptops for smaller data. ParaView is an application framework as well
as a turn-key application.
The ParaView code base is designed in such a way that all of its
components can be reused to quickly develop vertical
applications. This flexibility allows ParaView developers to quickly
develop applications that have specific functionality for a specific
problem domain. ParaView runs on distributed and shared memory
parallel and single processor systems.


%package        devel
Summary:        Development files for ParaView
Group:          Sciences/Other
Requires:       %{name} = %{version}-%{release}
Requires:       vtk-devel

%if %{with mpi}
%rename         paraview-mpi-devel
%endif

%description    devel
%{summary}.


%package -n %{staticdevelname}
Summary:        Static development files for ParaView
Group:          Sciences/Other
Provides:       paraview-static-devel = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
%if %{with mpi}
%rename         paraview-mpi-static-devel
%endif

%description -n %{staticdevelname}
%{summary}.


%prep
%autosetup -n ParaView-v%{version} -p1

sh %{_sourcedir}/cleansources.bash

%build
#(eatdirt) Those upstream punks fancy changing the name of the
#following options without notice. Inside the build directory,
#starting from a pristine configuration, ccmake ../ is your friend,
#"t" option activated

%cmake                                                                  \
        -DCMAKE_INSTALL_CMAKEDIR:PATH=%{_lib}/cmake                     \
        -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib}/%{name}                     \
        -DBUILD_EXAMPLES:BOOL=ON                                        \
        -DBUILD_TESTING:BOOL=OFF                                        \
        -DCMAKE_C_COMPILER=mpicc                                        \
        -DCMAKE_CXX_COMPILER=mpicxx                                     \
        -DCMAKE_CXX_FLAGS="%{paraflags}"                                \
        -DCMAKE_C_FLAGS="%{paraflags}"                                  \
        -DCMAKE_VERBOSE_MAKEFILE:BOOL=OFF                               \
        -DCMAKE_RULE_MESSAGES:BOOL=OFF                                  \
        -DPARAVIEW_DATA_ROOT:PATH=%{_datadir}                           \
        -DPARAVIEW_BUILD_WITH_EXTERNAL:BOOL=ON                          \
        -DPARAVIEW_USE_PYTHON:BOOL=ON                                   \
        -DPARAVIEW_ENABLE_FFMPEG:BOOL=ON                                \
        -DPARAVIEW_ENABLE_COSMOTOOLS:BOOL=OFF                           \
        -DPARAVIEW_INSTALL_DEVELOPMENT_FILES:BOOL=ON                    \
        -DVTK_PYTHON_VERSION=3                                          \
        -DPARAVIEW_VERSIONED_INSTALL:BOOL=OFF                           \
%if %{with mpi}
        -DPARAVIEW_USE_MPI:BOOL=ON                                      \
%else
        -DPARAVIEW_USE_MPI:BOOL=OFF                                     \
%endif
        -DVTK_INSTALL_DATA_DIR=share/paraview                           \
        -DVTK_INSTALL_PACKAGE_DIR=share/cmake/paraview                  \
        -DQtTesting_INSTALL_LIB_DIR:PATH=%{_lib}/%{namever}             \
        -DQtTesting_INSTALL_CMAKE_DIR:PATH=%{_lib}/%{namever}/CMake     \
        -DVTK_UNDEFINED_SYMBOLS_ALLOWED:BOOL=OFF                        \
        -DVTK_MODULE_USE_EXTERNAL_ParaView_vtkcatalyst:BOOL=OFF         \
        -DVTK_MODULE_USE_EXTERNAL_VTK_doubleconversion:BOOL=ON          \
        -DVTK_MODULE_USE_EXTERNAL_VTK_cli11:BOOL=OFF                    \
        -DVTK_MODULE_USE_EXTERNAL_VTK_eigen:BOOL=ON                     \
        -DVTK_MODULE_USE_EXTERNAL_VTK_expat:BOOL=ON                     \
        -DVTK_MODULE_USE_EXTERNAL_VTK_exprtk:BOOL=OFF                   \
        -DVTK_MODULE_USE_EXTERNAL_VTK_fmt:BOOL=ON                       \
        -DVTK_MODULE_USE_EXTERNAL_VTK_freetype:BOOL=ON                  \
        -DVTK_MODULE_USE_EXTERNAL_VTK_gl2ps:BOOL=OFF                    \
        -DVTK_MODULE_USE_EXTERNAL_VTK_glew:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_hdf5:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_ioss:BOOL=OFF                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_jpeg:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_jsoncpp:BOOL=ON                   \
        -DVTK_MODULE_USE_EXTERNAL_VTK_libharu:BOOL=OFF                  \
        -DVTK_MODULE_USE_EXTERNAL_VTK_libxml2:BOOL=ON                   \
        -DVTK_MODULE_USE_EXTERNAL_VTK_lz4:BOOL=ON                       \
        -DVTK_MODULE_USE_EXTERNAL_VTK_lzma:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_mpi4py:BOOL=ON                    \
        -DVTK_MODULE_USE_EXTERNAL_VTK_netcdf:BOOL=ON                    \
        -DVTK_MODULE_USE_EXTERNAL_VTK_ogg:BOOL=ON                       \
        -DVTK_MODULE_USE_EXTERNAL_VTK_png:BOOL=ON                       \
        -DVTK_MODULE_USE_EXTERNAL_VTK_protobuf:BOOL=ON                  \
        -DVTK_MODULE_USE_EXTERNAL_VTK_pugixml:BOOL=ON                   \
        -DVTK_MODULE_USE_EXTERNAL_VTK_theora:BOOL=ON                    \
        -DVTK_MODULE_USE_EXTERNAL_VTK_tiff:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_utf8:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_zlib:BOOL=ON                      \
        -DVTK_MODULE_ENABLE_ParaView_VTKExtensionsCGNSReader:BOOL=NO    \
        -DVTK_MODULE_ENABLE_ParaView_VTKExtensionsCGNSWriter:BOOL=NO    \
        -DVTK_INSTALL_INCLUDE_DIR:PATH=include/%{name}                  \
        -DVTK_INSTALL_ARCHIVE_DIR:PATH=%{_lib}/%{name}                  \
        -DVTK_INSTALL_LIBRARY_DIR:PATH=%{_lib}/%{name}                  \
        -DQtTesting_INSTALL_LIB_DIR=%{_lib}/%{name}                     \
        -DQtTesting_INSTALL_CMAKE_DIR=%{_lib}/%{name}/CMake

%cmake_build

%install
%cmake_install

# Install MIME type and desktop file
install -D -m644 %{SOURCE1} %{buildroot}%{_datadir}/mime/packages/%{name}.xml
install -D -m644 %{SOURCE2} %{buildroot}%{_datadir}/applications/%{name}.desktop

# Use our own .desktop file
rm -r %{buildroot}%{_datadir}/applications/org.paraview.ParaView.desktop

# ld.conf.d file
install -d %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo %{_libdir}/%{namever} > %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf

#Cleanup only vtk conflicting binaries
rm %{buildroot}%{_bindir}/vtk{ParseJava,Wrap{Hierarchy,Java,Python}}*


%files
%license %{_datadir}/licenses/ParaView/
%doc %{_docdir}/ParaView/
%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%{_bindir}/paraview
%{_bindir}/pv*
%{_bindir}/smTestDriver*
%{_bindir}/paraview-config
%{_bindir}/paraview.conf
%{_libdir}/paraview/
%{_datadir}/applications/paraview.desktop
%{_datadir}/mime/packages/paraview.xml
%{_metainfodir}/org.paraview.ParaView.appdata.xml
%{_datadir}/paraview/
%{_iconsdir}/hicolor/*/apps/paraview.png
%exclude %{_libdir}/paraview/*.a

%files          devel
%{_bindir}/vtkProcessXML
%{_bindir}/vtkWrap*
%{_bindir}/vtkProbeOpenGLVersion*
%{_includedir}/paraview/
%{_libdir}/cmake/paraview/

%files -n %{staticdevelname}
%{_libdir}/paraview/*.a


%changelog
* Thu Mar 23 2023 daviddavid <daviddavid> 5.10.1-7.mga9
+ Revision: 1950175
- drop no more needed by the project Qt5WebKit build dependency

* Mon Dec 12 2022 ns80 <ns80> 5.10.1-6.mga9
+ Revision: 1921093
- rebuild for new libtiff

* Mon Dec 05 2022 papoteur <papoteur> 5.10.1-5.mga9
+ Revision: 1918310
- rebuild for hdf5 1.12.2

* Sun Oct 09 2022 papoteur <papoteur> 5.10.1-4.mga9
+ Revision: 1895672
- Rebuild for libfmt9

* Sat Aug 27 2022 eatdirt <eatdirt> 5.10.1-3.mga9
+ Revision: 1881276
- Rebuild for new cgns

* Mon Apr 11 2022 papoteur <papoteur> 5.10.1-2.mga9
+ Revision: 1848895
- Exclude libcatalyst.so from requires

* Sun Apr 10 2022 papoteur <papoteur> 5.10.1-1.mga9
+ Revision: 1848618
- fix for building with external fmt
- Use external fmt library
- update to 5.10.1
- fix build with ffmpeg 5.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 5.9.1-2.mga9
+ Revision: 1786860
- rebuild for python-3.10

* Mon Dec 13 2021 wally <wally> 5.9.1-1.mga9
+ Revision: 1762008
- new version 5.9.1

* Mon Dec 13 2021 wally <wally> 5.8.1-11.mga9
+ Revision: 1762007
- drop upstream .desktop file and use our own
- don't own system dirs
- fix build with GCC 11
- rebuild for netcdf 4.8.1

* Thu Mar 25 2021 daviddavid <daviddavid> 5.8.1-10.mga9
+ Revision: 1710201
- add patch to fix detection of Python 3.9
- rebuild for python 3.9

* Fri Dec 18 2020 luigiwalser <luigiwalser> 5.8.1-9.mga8
+ Revision: 1660991
- rebuild for protobuf

* Thu Dec 17 2020 umeabot <umeabot> 5.8.1-8.mga8
+ Revision: 1659284
- Rebuild for new Qt5

* Wed Dec 02 2020 luigiwalser <luigiwalser> 5.8.1-7.mga8
+ Revision: 1651367
- rebuild for glew

* Mon Nov 30 2020 luigiwalser <luigiwalser> 5.8.1-6.mga8
+ Revision: 1650542
- rebuild for protobuf
- rebuild for jsoncpp

* Mon Oct 26 2020 akien <akien> 5.8.1-4.mga8
+ Revision: 1639619
- Rebuild against libnetcdf18

* Thu Oct 22 2020 joequant <joequant> 5.8.1-3.mga8
+ Revision: 1637933
- fix freetype

* Thu Oct 08 2020 joequant <joequant> 5.8.1-2.mga8
+ Revision: 1632874
- require openmpi

* Thu Oct 08 2020 joequant <joequant> 5.8.1-1.mga8
+ Revision: 1632815
- remove conflict with vtk-devel - bug 27335
+ pterjan <pterjan>
- Rebuild for new netcdf on arm

* Sun Jun 28 2020 daviddavid <daviddavid> 5.8.0-7.mga8
+ Revision: 1600178
- rebuild for new protobuf 3.12.3
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Mon Mar 23 2020 eatdirt <eatdirt> 5.8.0-6.mga8
+ Revision: 1559133
- Fix dead links in usr/bin

* Mon Mar 23 2020 eatdirt <eatdirt> 5.8.0-5.mga8
+ Revision: 1559038
- Rebuild for new cgns, try increasing cpus count on 32bits

* Sun Mar 22 2020 eatdirt <eatdirt> 5.8.0-3.mga8
+ Revision: 1558873
- Reduce ncpu for ix86 and arm
- Update the monster to version 5.8.0
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Dec 19 2019 daviddavid <daviddavid> 5.6.0-7.mga8
+ Revision: 1468855
- rebuild for new protobuf 3.11.2

* Mon Oct 07 2019 daviddavid <daviddavid> 5.6.0-6.mga8
+ Revision: 1450325
- add upstream patch to fix build with python3.8
- rebuild for new double-conversion 3.1.5
+ eatdirt <eatdirt>
- Rebuild for new python

* Sun Mar 31 2019 umeabot <umeabot> 5.6.0-4.mga7
+ Revision: 1383855
- Qt5 Rebuild

* Fri Mar 08 2019 eatdirt <eatdirt> 5.6.0-3.mga7
+ Revision: 1372918
- Tentative fix of gcc being killed
- Rebuild for new cgns

* Sun Jan 13 2019 zezinho <zezinho> 5.6.0-1.mga7
+ Revision: 1356087
- new version 5.6.0
- limit build cpus to fix build errors
- some patches to disable bogus doc build
- patch to fix build with python 3.7
+ tmb <tmb>
- rebuild for python 3.7
+ tv <tv>
- rebuild with python 3.7

* Fri Nov 09 2018 daviddavid <daviddavid> 5.5.2-3.mga7
+ Revision: 1329067
- rebuild for new hdf5 1.10.4

* Sun Sep 23 2018 umeabot <umeabot> 5.5.2-2.mga7
+ Revision: 1300107
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 eatdirt <eatdirt> 5.5.2-1.mga7
+ Revision: 1249771
- Upgrade to version 5.5.2

* Sun Jun 03 2018 daviddavid <daviddavid> 5.4.1-5.mga7
+ Revision: 1233841
- add patch to fix build with new Qt5 >= 5.11.0

* Fri May 18 2018 eatdirt <eatdirt> 5.4.1-4.mga7
+ Revision: 1230352
- Rebuild for new openmpi

* Tue May 01 2018 daviddavid <daviddavid> 5.4.1-3.mga7
+ Revision: 1224199
- add upstream patch to fix build with jsoncpp-1.8.4
- rebuild for new ffmpeg 4.0

* Sun Apr 15 2018 daviddavid <daviddavid> 5.4.1-2.mga7
+ Revision: 1219040
- rebuild for new protobuf 3.5
- use new python provides

* Wed Oct 11 2017 eatdirt <eatdirt> 5.4.1-1.mga7
+ Revision: 1171044
- Upgrade to version 5.4.1

* Mon Oct 09 2017 eatdirt <eatdirt> 5.3.0-2.mga7
+ Revision: 1170570
- Rebuild for new openmpi

* Tue May 02 2017 eatdirt <eatdirt> 5.3.0-1.mga6
+ Revision: 1098639
- Upgrade to version 5.3

* Tue May 02 2017 akien <akien> 5.2.0-6.mga6
+ Revision: 1098317
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 5.2.0-5.mga6
+ Revision: 1090232
- Rebuild for ffmpeg 3.2.4

* Mon Jan 02 2017 akien <akien> 5.2.0-4.mga6
+ Revision: 1079605
- Rebuild for libjsoncpp changed soname

* Tue Dec 13 2016 eatdirt <eatdirt> 5.2.0-2.mga6
+ Revision: 1074744
- Package static libs needed by openfoam

* Fri Dec 09 2016 eatdirt <eatdirt> 5.2.0-1.mga6
+ Revision: 1073751
- Swithching off verbosity to not be killed by the iurt 100M log bloody limit
- Upgrade to version 5.2.0 for new openmpi
+ tmb <tmb>
- rebuild for new openmpi
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Sep 30 2015 eatdirt <eatdirt> 4.1.0-12.mga6
+ Revision: 885299
- Rebuild for new openmpi

* Fri Aug 28 2015 cjw <cjw> 4.1.0-11.mga6
+ Revision: 870419
- rebuild with gcc 5

* Tue Jul 21 2015 daviddavid <daviddavid> 4.1.0-10.mga6
+ Revision: 855907
- rebuild with new hdf5

* Sat Feb 07 2015 joequant <joequant> 4.1.0-9.mga5
+ Revision: 813925
- add fedora vtk patch
- rebuild

* Fri Nov 14 2014 akien <akien> 4.1.0-8.mga5
+ Revision: 797028
- Rebuild for ffmpeg 2.4

* Wed Oct 15 2014 umeabot <umeabot> 4.1.0-7.mga5
+ Revision: 740353
- Second Mageia 5 Mass Rebuild

* Tue Oct 07 2014 fwang <fwang> 4.1.0-6.mga5
+ Revision: 737310
- paraview 4.1 does not like protobuf 2.6
- add patch from upstarem to build with mesagl > 10.3
- try to build with protobuf 2.6
+ tv <tv>
- rebuild so that it picks typelib() requires
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild
+ luigiwalser <luigiwalser>
- rebuild for protobuf

* Wed Jul 23 2014 akien <akien> 4.1.0-3.mga5
+ Revision: 655873
- Set desktop category to DataVisualization

* Tue Jul 22 2014 akien <akien> 4.1.0-2.mga5
+ Revision: 655678
- Fix missing content in %%files
- Use new upstream icon (and drop SOURCE3)
- Sync patches with Fedora:
  o Install missing headers (rhbz#1100911)
  o Install TopologicalSort.cmake (rhbz#1116521)
  o Adjust ParaViewPlugins.cmake for Fedora packaging (rhbz#118520), adapted to Mageia

* Tue Jul 22 2014 akien <akien> 4.1.0-1.mga5
+ Revision: 655598
- Make sure everything gets installed to paraview-4.1 subdirectories
  (we could sync with Fedora and drop the suffix)
- Add a workaround for gcc#61294 preventing linking
- Syncing patches with Fedora
- Improve use of system libraries with new cmake arguments and BRs
- Require paraview-data and move icon and mime-type to main package
+ philippem <philippem>
- import Debian patch, use make instead of %%make
- Install python properly

* Sat Nov 02 2013 fwang <fwang> 4.0.1-3.mga4
+ Revision: 548943
- add requires on python-gi

* Sat Oct 19 2013 umeabot <umeabot> 4.0.1-2.mga4
+ Revision: 530730
- Mageia 4 Mass Rebuild

* Sun Jul 28 2013 joequant <joequant> 4.0.1-1.mga4
+ Revision: 459401
- add vtkpython patch
- make _bindir explicit and remove python packages
- remove missing pvblot
- update to 4.0.1
- fix change in CodecID type in ffmpeg
- add comment for rpmlint issue
- remove unneeded spec commands
- fix rpmlint issues
- imported package paraview

